@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from cStringIO import StringIO
 from plone.app.caching.interfaces import IPloneCacheSettings
 from plone.app.caching.testing import PLONE_APP_CACHING_FUNCTIONAL_TESTING
 from plone.app.caching.tests.test_utils import stable_now
@@ -23,7 +22,8 @@ import dateutil.parser
 import dateutil.tz
 import os
 import pkg_resources
-import unittest2 as unittest
+import six
+import unittest
 
 
 TEST_FILE = pkg_resources.resource_filename(
@@ -36,8 +36,8 @@ def test_image():
         'plone.app.caching.tests', 'test.gif')
     filename = os.path.join(os.path.dirname(__file__), u'test.gif')
     return NamedBlobImage(
-        data=open(filename, 'r').read(),
-        filename=filename
+        data=open(filename, 'rb').read(),
+        filename=filename,
     )
 
 
@@ -62,10 +62,6 @@ class TestProfileWithoutCaching(unittest.TestCase):
         self.app = self.layer['app']
         self.portal = self.layer['portal']
 
-        test_css = FSFile('test.css', os.path.join(
-            os.path.dirname(__file__), 'test.css'))
-        self.portal.portal_skins.custom._setOb('test.css', test_css)
-
         setRequest(self.portal.REQUEST)
 
         applyProfile(self.portal, 'plone.app.caching:without-caching-proxy')
@@ -91,19 +87,19 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # Add folder content
         setRoles(self.portal, TEST_USER_ID, ('Manager',))
         self.portal.invokeFactory('Folder', 'f1')
-        self.portal['f1'].title = u"Folder one"
-        self.portal['f1'].description = u"Folder one description"
+        self.portal['f1'].title = u'Folder one'
+        self.portal['f1'].description = u'Folder one description'
         self.portal['f1'].reindexObject()
 
         # Add page content
         self.portal['f1'].invokeFactory('Document', 'd1')
-        self.portal['f1']['d1'].title = u"Document one"
-        self.portal['f1']['d1'].description = u"Document one description"
+        self.portal['f1']['d1'].title = u'Document one'
+        self.portal['f1']['d1'].description = u'Document one description'
         testText = 'Testing... body one'
         self.portal['f1']['d1'].text = RichTextValue(
             testText,
             'text/plain',
-            'text/html'
+            'text/html',
         )
         self.portal['f1']['d1'].reindexObject()
 
@@ -124,7 +120,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
         import transaction
         transaction.commit()
 
-        # Request the quthenticated folder
+        # Request the authenticated folder
         now = stable_now()
         browser = Browser(self.app)
         browser.addHeader(
@@ -139,12 +135,12 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        tag = '"|test_user_1_|{0}|en|{1}|0|0'.format(
+        tag = '"|test_user_1_|{0}|en|{1}|0'.format(
             catalog.getCounter(),
             default_skin,
         )
         self.assertEqual(tag, _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Set the copy/cut cookie and then request the folder view again
@@ -157,7 +153,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        tag = '"|test_user_1_|{0}|en|{1}|0|1'.format(
+        tag = '"|test_user_1_|{0}|en|{1}|0'.format(
             catalog.getCounter(),
             default_skin,
         )
@@ -171,7 +167,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
             'Basic {0}:{1}'.format(TEST_USER_NAME, TEST_USER_PASSWORD, ),
         )
         browser.open(self.portal['f1']['d1'].absolute_url())
-        self.assertTrue(testText in browser.contents)
+        self.assertIn(testText, browser.contents)
         self.assertEqual('plone.content.itemView',
                          browser.headers['X-Cache-Rule'])
         self.assertEqual('plone.app.caching.weakCaching',
@@ -179,12 +175,12 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        tag = '"|test_user_1_|{0}|en|{1}|0'.format(
+        tag = '"|test_user_1_|{0}|en|{1}'.format(
             catalog.getCounter(),
             default_skin,
         )
         self.assertEqual(tag, _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the authenticated page again -- to test RAM cache.
@@ -199,7 +195,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
         # Authenticated should NOT be RAM cached
-        self.assertEqual(None, browser.headers.get('X-RAMCache'))
+        self.assertIsNone(browser.headers.get('X-RAMCache'))
 
         # Request the authenticated page again -- with an INM header to test
         # 304
@@ -214,7 +210,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
         browser.open(self.portal['f1']['d1'].absolute_url())
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request the anonymous folder
         now = stable_now()
@@ -227,9 +223,9 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        tag = '"||{0}|en|{1}|0|0'.format(catalog.getCounter(), default_skin)
+        tag = '"||{0}|en|{1}|0'.format(catalog.getCounter(), default_skin)
         self.assertEqual(tag, _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the anonymous page
@@ -240,13 +236,13 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Rule'])
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
-        self.assertTrue(testText in browser.contents)
+        self.assertIn(testText, browser.contents)
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        tag = '"||{0}|en|{1}|0'.format(catalog.getCounter(), default_skin)
+        tag = '"||{0}|en|{1}'.format(catalog.getCounter(), default_skin)
         self.assertEqual(tag, _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the anonymous page again -- to test RAM cache.
@@ -261,12 +257,12 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # This should come from RAM cache
         self.assertEqual('plone.app.caching.operations.ramcache',
                          browser.headers['X-RAMCache'])
-        self.assertTrue(testText in browser.contents)
+        self.assertIn(testText, browser.contents)
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        tag = '"||{0}|en|{1}|0'.format(catalog.getCounter(), default_skin)
+        tag = '"||{0}|en|{1}'.format(catalog.getCounter(), default_skin)
         self.assertEqual(tag, _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the anonymous page again -- with an INM header to test 304.
@@ -281,14 +277,14 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Edit the page to update the etag
         testText2 = 'Testing... body two'
         self.portal['f1']['d1'].text = RichTextValue(
             testText2,
             'text/plain',
-            'text/html'
+            'text/html',
         )
         self.portal['f1']['d1'].reindexObject()
 
@@ -305,8 +301,8 @@ class TestProfileWithoutCaching(unittest.TestCase):
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
         # The etag has changed so we should get a fresh page.
-        self.assertEqual(None, browser.headers.get('X-RAMCache'))
-        self.assertEqual('200 Ok', browser.headers['Status'])
+        self.assertIsNone(browser.headers.get('X-RAMCache'))
+        self.assertEqual('200 OK', browser.headers['Status'].upper())
 
     def test_content_feeds(self):
 
@@ -334,7 +330,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         tag = '"||{0}|en|{1}"'.format(catalog.getCounter(), default_skin)
         self.assertEqual(tag, browser.headers['ETag'])
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the rss feed again -- to test RAM cache
@@ -353,7 +349,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         tag = '"||{0}|en|{1}"'.format(catalog.getCounter(), default_skin)
         self.assertEqual(tag, browser.headers['ETag'])
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the rss feed again -- with an INM header to test 304.
@@ -367,7 +363,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request the authenticated rss feed
         now = stable_now()
@@ -376,7 +372,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
             'Authorization', 'Basic {0}:{1}'.format(
                 TEST_USER_NAME,
                 TEST_USER_PASSWORD,
-            )
+            ),
         )
         browser.open(self.portal.absolute_url() + '/RSS')
         self.assertEqual('plone.content.feed', browser.headers['X-Cache-Rule'])
@@ -387,7 +383,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         self.assertEqual('"|test_user_1_|{0}|en|{1}"'.format(
             catalog.getCounter(), default_skin), browser.headers['ETag'])
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the authenticated rss feed again -- to test RAM cache
@@ -396,28 +392,28 @@ class TestProfileWithoutCaching(unittest.TestCase):
             'Authorization', 'Basic {0}:{1}'.format(
                 TEST_USER_NAME,
                 TEST_USER_PASSWORD,
-            )
+            ),
         )
         browser.open(self.portal.absolute_url() + '/RSS')
         self.assertEqual('plone.content.feed', browser.headers['X-Cache-Rule'])
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
         # Authenticated should NOT be RAM cached
-        self.assertEqual(None, browser.headers.get('X-RAMCache'))
+        self.assertIsNone(browser.headers.get('X-RAMCache'))
 
     def test_content_files(self):
 
         # Add folder content
         setRoles(self.portal, TEST_USER_ID, ('Manager',))
         self.portal.invokeFactory('Folder', 'f1')
-        self.portal['f1'].title = u"Folder one"
-        self.portal['f1'].description = u"Folder one description"
+        self.portal['f1'].title = u'Folder one'
+        self.portal['f1'].description = u'Folder one description'
         self.portal['f1'].reindexObject()
 
         # Add content image
         self.portal['f1'].invokeFactory('Image', 'i1')
-        self.portal['f1']['i1'].title = u"Image one"
-        self.portal['f1']['i1'].description = u"Image one description"
+        self.portal['f1']['i1'].title = u'Image one'
+        self.portal['f1']['i1'].description = u'Image one description'
         self.portal['f1']['i1'].image = test_image()
         self.portal['f1']['i1'].reindexObject()
 
@@ -439,7 +435,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the image again -- with an IMS header to test 304
@@ -453,7 +449,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request an image scale
         now = stable_now()
@@ -468,7 +464,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
     def test_resources(self):
@@ -489,7 +485,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
         timedelta = dateutil.parser.parse(browser.headers['Expires']) - now
-        self.assertTrue(timedelta > datetime.timedelta(seconds=86390))
+        self.assertGreater(timedelta, datetime.timedelta(seconds=86390))
 
         # Request the skin image again -- with an IMS header to test 304
         lastmodified = browser.headers['Last-Modified']
@@ -502,7 +498,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request a large datafile (over 64K) to test files that use
         # the "response.write()" function to initiate a streamed response.
@@ -510,9 +506,11 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # large OFS.Image.Image, large non-blog ATImages/ATFiles, and
         # large Resource Registry cooked files, which all use the same
         # method to initiate a streamed response.
-        s = 'a' * (1 << 16) * 3
-        self.portal.manage_addFile('bigfile', file=StringIO(
-            s), content_type='application/octet-stream')
+        s = b'a' * (1 << 16) * 3
+        self.portal.manage_addFile(
+            'bigfile',
+            file=six.BytesIO(s),
+            content_type='application/octet-stream')
 
         import transaction
         transaction.commit()
@@ -528,7 +526,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
         timedelta = dateutil.parser.parse(browser.headers['Expires']) - now
-        self.assertTrue(timedelta > datetime.timedelta(seconds=86390))
+        self.assertGreater(timedelta, datetime.timedelta(seconds=86390))
 
     def test_stable_resources(self):
         # We don't actually have any non-RR stable resources yet
